@@ -15,7 +15,9 @@ static const R_CallMethodDef callMethods[]  = {
   { "ps__boot_time",          (DL_FUNC) ps__boot_time,          0 },
   { "ps__cpu_count_logical",  (DL_FUNC) ps__cpu_count_logical,  0 },
   { "ps__cpu_count_physical", (DL_FUNC) ps__cpu_count_physical, 0 },
+  { "ps__system_cpu_times",   (DL_FUNC) ps__system_cpu_times,   0 },
   { "ps__users",              (DL_FUNC) ps__users,              0 },
+  { "ps__loadavg",            (DL_FUNC) ps__loadavg,            1 },
   { "ps__tty_size",           (DL_FUNC) ps__tty_size,           0 },
   { "ps__disk_partitions",    (DL_FUNC) ps__disk_partitions,    1 },
   { "ps__disk_usage",         (DL_FUNC) ps__disk_usage,         1 },
@@ -54,6 +56,7 @@ static const R_CallMethodDef callMethods[]  = {
   { "psll_connections",  (DL_FUNC) psll_connections,  1 },
   { "psll_get_nice",     (DL_FUNC) psll_get_nice,     1 },
   { "psll_set_nice",     (DL_FUNC) psll_set_nice,     2 },
+  { "psll_dlls",         (DL_FUNC) psll_dlls,         1 },
 
   /* Utils */
   { "ps__init",          (DL_FUNC) ps__init,          2 },
